use std::fmt::{Debug, Display};

#[derive(thiserror::Error, Debug)]
#[error("No user info found")]
pub struct NoUserInfo;

#[derive(thiserror::Error, Debug)]
#[error("Handler was already used")]
pub struct HandlerUsed;

#[derive(thiserror::Error, Debug)]
pub enum InvalidCommand {
    #[error("Invalid params")]
    InvalidParams,
    #[error("Not enough bytes in the name's hash")]
    InvalidOutputLength,
    #[error("Error decoding the values: {0}")]
    NameDecodingError(#[from] base64::DecodeError),
    #[error("Unknown locale passed into callback")]
    UnknownLocale,
}

#[inline]
pub fn handle_error<T>(error: T)
where
    T: Debug + Display,
{
    log::error!("{error}\n{error:?}");
}

pub struct ErrorHandler;

impl teloxide::error_handlers::ErrorHandler<crate::Error> for ErrorHandler {
    #[inline]
    fn handle_error(
        self: std::sync::Arc<Self>,
        error: crate::Error,
    ) -> futures::prelude::future::BoxFuture<'static, ()> {
        handle_error(error);
        Box::pin(async {})
    }
}
